==> prestashop_1.4.10.0.zip: prestashop/modules/jirafe/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{jirafe}prestashop>adminjirafedashboard14_2938c7f7e560ed972f8a4f68e80ff834'] = 'Cuadro de mandos';
$_MODULE['<{jirafe}prestashop>adminjirafedashboard15_2938c7f7e560ed972f8a4f68e80ff834'] = 'Cuadro de mandos';
$_MODULE['<{jirafe}prestashop>jirafe14_82add7330a3c66e05500eeccd39aa469'] = 'Analytics para comercio electrónico';
$_MODULE['<{jirafe}prestashop>jirafe14_f93559b97ae7a2b76690eba69254919c'] = 'Los mejores análisis para los comerciantes de comercio electrónico. Profundamente integrado en la plataforma Prestashop.';
$_MODULE['<{jirafe}prestashop>jirafe14_3500917073661abe35d86b0575fa1a7d'] = '¿Está seguro que desea eliminar Jirafe la integración de análisis de su sitio?';
$_MODULE['<{jirafe}prestashop>jirafe14_fd1a630991b8c193765c69892543555d'] = 'El servicio Web Jirafe es inalcanzable. Por favor, inténtelo de nuevo cuando se restablece la conexión.';
$_MODULE['<{jirafe}prestashop>jirafe15_82add7330a3c66e05500eeccd39aa469'] = 'Analytics para comercio electrónico';
$_MODULE['<{jirafe}prestashop>jirafe15_f93559b97ae7a2b76690eba69254919c'] = 'Los mejores análisis para los comerciantes de comercio electrónico. Profundamente integrado en la plataforma Prestashop.';
$_MODULE['<{jirafe}prestashop>jirafe15_3500917073661abe35d86b0575fa1a7d'] = '¿Está seguro que desea eliminar Jirafe la integración de análisis de su sitio?';
$_MODULE['<{jirafe}prestashop>jirafe15_fd1a630991b8c193765c69892543555d'] = 'El servicio Web Jirafe es inalcanzable. Por favor, inténtelo de nuevo cuando se restablece la conexión.';

==> prestashop_1.4.11.1.zip: prestashop/modules/jirafe/es.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{jirafe}prestashop>adminjirafedashboard14_2938c7f7e560ed972f8a4f68e80ff834'] = 'Cuadro de mandos';
$_MODULE['<{jirafe}prestashop>adminjirafedashboard15_2938c7f7e560ed972f8a4f68e80ff834'] = 'Cuadro de mandos';
$_MODULE['<{jirafe}prestashop>jirafe14_82add7330a3c66e05500eeccd39aa469'] = 'Analytics para comercio electrónico';
$_MODULE['<{jirafe}prestashop>jirafe14_f93559b97ae7a2b76690eba69254919c'] = 'Los mejores análisis para los comerciantes de comercio electrónico. Profundamente integrado en la plataforma Prestashop.';
$_MODULE['<{jirafe}prestashop>jirafe14_3500917073661abe35d86b0575fa1a7d'] = '¿Está seguro que desea eliminar Jirafe la integración de análisis de su sitio?';
$_MODULE['<{jirafe}prestashop>jirafe14_fd1a630991b8c193765c69892543555d'] = 'El servicio Web Jirafe es inalcanzable. Por favor, inténtelo de nuevo cuando se restablece la conexión.';
$_MODULE['<{jirafe}prestashop>jirafe14_94a08da1fecbb6e8b46990538c7b50b2'] = 'token';
$_MODULE['<{jirafe}prestashop>jirafe14_d8e87c0927539672f54462c837be0b7f'] = 'Sincronizar';
$_MODULE['<{jirafe}prestashop>jirafe15_82add7330a3c66e05500eeccd39aa469'] = 'Analytics para comercio electrónico';
$_MODULE['<{jirafe}prestashop>jirafe15_f93559b97ae7a2b76690eba69254919c'] = 'Los mejores análisis para los comerciantes de comercio electrónico. Profundamente integrado en la plataforma Prestashop.';
$_MODULE['<{jirafe}prestashop>jirafe15_3500917073661abe35d86b0575fa1a7d'] = '¿Está seguro que desea eliminar Jirafe la integración de análisis de su sitio?';
$_MODULE['<{jirafe}prestashop>jirafe15_fd1a630991b8c193765c69892543555d'] = 'El servicio Web Jirafe es inalcanzable. Por favor, inténtelo de nuevo cuando se restablece la conexión.';
